Get Feeds
=========
Feeds is meant to be installed on your server and run periodically in a cron
job or similar job scheduler. We recommend to install Feeds inside a virtual
environment.

Feeds can be installed from PyPI using ``pip``:

.. code-block:: bash

   $ pip install PyFeeds

You may also install the current development version:

.. code-block:: bash

   $ pip install https://github.com/pyfeeds/pyfeeds/archive/master.tar.gz

After installation ``feeds`` is available in your virtual environment.

Feeds supports Python 3.6+.
